hgext/schemes.py
changeset 29841 d5883fd055c6
parent 29205 a0939666b836
child 30640 7a3e67bfa417
--- a/hgext/schemes.py	Thu Aug 25 01:00:26 2016 -0400
+++ b/hgext/schemes.py	Tue Aug 23 11:26:08 2016 -0400
@@ -56,11 +56,11 @@
 
 cmdtable = {}
 command = cmdutil.command(cmdtable)
 # Note for extension authors: ONLY specify testedwith = 'internal' for
 # extensions which SHIP WITH MERCURIAL. Non-mainline extensions should
 # be specifying the version(s) of Mercurial they are tested with, or
 # leave the attribute unspecified.
-testedwith = 'internal'
+testedwith = 'ships-with-hg-core'
 
 
 class ShortRepository(object):
@@ -56,11 +56,11 @@
 cmdtable = {}
 command = cmdutil.command(cmdtable)
-# Note for extension authors: ONLY specify testedwith = 'internal' for
+# Note for extension authors: ONLY specify testedwith = 'ships-with-hg-core' for
 # extensions which SHIP WITH MERCURIAL. Non-mainline extensions should
 # be specifying the version(s) of Mercurial they are tested with, or